{% load i18n %}

{% with choices.0 as choice %}
    <div class="flex flex-col mb-6">
        <h3 class="font-medium mb-2 text-gray-700 text-sm dark:text-gray-200">{% blocktrans with filter_title=title %}By {{ filter_title }}{% endblocktrans %}</h3>

        <div class="flex flex-row gap-4">
            {% for field in choice.form %}
                <div class="group relative w-1/2{% if field.errors %} errors{% endif %}">
                    {{ field }}

                    {% include "unfold/helpers/form_errors.html" with errors=field.errors %}
                </div>
            {% endfor %}
        </div>
    </div>
{% endwith %}
