<div class="flex group mb-6 flex-col last:mb-4">
    <label class="block font-medium mb-2 text-gray-900 text-sm dark:text-gray-200">
        {{ title }}
    </label>

    <div class="readonly bg-gray-50 border font-medium max-w-2xl px-3 py-2 rounded-md shadow-sm text-gray-500 text-sm dark:border-gray-700 dark:bg-gray-800 dark:text-gray-400">
        {{ value }}
    </div>
</div>
