<div class="flex flex-row">
    {% include 'django/forms/widgets/input.html' %}

    {% if related_url %}
        <a href="{{ related_url }}" class="related-lookup related-widget-wrapper-link view-related bg-white border cursor-pointer flex items-center h-9.5 justify-center ml-2 rounded shadow-sm shrink-0 text-gray-400 text-sm w-9.5 hover:text-gray-700 dark:bg-gray-900 dark:border-gray-700 dark:text-gray-500 dark:hover:text-gray-200" id="lookup_id_{{ widget.name }}" title="{{ link_title }}">
            <span class="material-symbols-outlined text-sm">search</span>
        </a>
    {% endif %}
</div>

{% if link_label %}
    <strong class="mt-2 font-medium text-xs">
        {% if link_url %}
            <a href="{{ link_url }}" class="underline text-primary-500">
                {{ link_label }}
            </a>
        {% else %}
            {{ link_label }}
        {% endif %}
    </strong>
{% endif %}
